@@ -1,11 +1,11 @@
 """
-Comp-LEO SDK: Compliance & Security for Leo Smart Contracts
+Comp-LEO SDK: Compliance and security analysis for Leo smart contracts.
 
 Automated compliance checking, security analysis, and policy enforcement
 for the Aleo ecosystem.
 """
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __author__ = "CompliLedger"
 __license__ = "Apache-2.0"
 
